@@ -47,7 +47,7 @@ Example usage (from `vuespa/__init__.py`):
                 */
               httpHandler: (cb: {(url: string): void}, fns: {[name: string]: {(args: any): void}}) => {(): void},
               // Call a remote method, and update `name` on this local Vue instance.
-              update: (name: string, fn: string, ...args: any[]),
+              update: (name: string, fn: string, ...args: any[]) => Promise<void>,
             };
           }
         }
@@ -89,7 +89,7 @@ class VueSpa:
         return self._port_vue
 
     def __init__(self, vue_path, client_class, host=None, port=None,
-            development=True, config_web_callback=None):
+            development=True, config_web_callback=None, max_msg_size=1024**3):
         """
         Args:
             vue_path: File system path to Vue application.
@@ -118,6 +118,8 @@ class VueSpa:
                         u8[i] = newVal.charCodeAt(i);
                       }
                       (this.$refs.pluginIframe as any).src = URL.createObjectURL(new Blob([u8]));
+            max_msg_size: Maximum websocket message size that the server should
+                accept. Defaults to 1GB.
         """
         self._vue_path = vue_path
         self._client_class = client_class
@@ -133,6 +135,7 @@ class VueSpa:
         self._port = port
         self._port_vue = None
         self._websocket_clients = {}
+        self._max_msg_size = max_msg_size
 
 
     def run(self):
@@ -288,7 +291,8 @@ class VueSpa:
         elif 'Upgrade' in req.headers:
             # Forward Vue's websocket.
             async with aiohttp.ClientSession() as session:
-                ws_response = web.WebSocketResponse()
+                ws_response = web.WebSocketResponse(
+                        max_msg_size=self._max_msg_size)
                 await ws_response.prepare(req)
 
                 async def ws_forward(ws_from, ws_to):
@@ -403,11 +407,15 @@ class VueSpa:
                     }
                     VueSpaBackend._socket.send(msg);
                 },
+                _getClientApiUrl: function() {
+                    return new URL('vuespa.ws.http/' + VueSpaBackend._clientId,
+                            window.location).href;
+                },
                 _setClientId: function(clientId, clientConnected) {
                     VueSpaBackend._clientId = clientId;
                     VueSpaBackend._clientConntected = clientConnected;
 
-                    let value = new URL('vuespa.ws.http/' + clientId, window.location).href;
+                    let value = this._getClientApiUrl();
                     if (!clientConnected) value = null;
                     for (const h of VueSpaBackend._httpHandlers) {
                         h[0](value);
@@ -498,7 +506,7 @@ class VueSpa:
                     const config = [newIdCallback, methodsArray];
                     VueSpaBackend._httpHandlers.push(config);
                     if (VueSpaBackend._clientId !== null)
-                        config[0](VueSpaBackend._clientId);
+                        config[0](VueSpaBackend._getClientApiUrl());
                     return () => {
                         VueSpaBackend._httpHandlers = VueSpaBackend._httpHandlers.filter(
                                 (x) => x !== config);
@@ -615,11 +623,13 @@ class VueSpa:
                 'err': None,
         }
         try:
+            args = dict(await req.post())
+            args.update(req.query)
             await ws_client._socket.send_str(json.dumps({
                 'type': 'http',
                 'fn': fn_id,
                 'id': web_id,
-                'args': dict(req.query),
+                'args': args,
             }))
             await socket_req['event'].wait()
         finally:
